@@ -20,6 +20,8 @@ def write_data(file_name, data):
     config = _config()
     if isinstance(data, pd.DataFrame):
         data = data.to_csv(index=False).encode()
+    elif isinstance(data,(np.ndarray, np.generic)):
+        data = data.tobytes()
     _put_object(config, config['bucket_name'], data, file_name)
 
 
